=====================
Installation variants
=====================

There are two variants for the installation plus a deprecated one.
(The deprecated installation variant will be removed in the next major
release.)

.. toctree::
   :maxdepth: 1

   Guided package installation (to be preferred) <guidedinstallation>
   Manual package installation (deprecated -- slightly more control over the installation process) <manualinstallation>
   upgrade-installation-manual-to-guided
   Source installation (for development) <sourceinstallation>
